# StandaloneRulesCleanupStatus

status for StandaloneRulesCleanup

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**bundles_deleted** | **[str]** | the bundles that were deleted | [optional] 
**rule_policies_deleted** | **[str]** | the rule policies that were deleted | [optional] 
**labels_deleted** | [**[StandaloneRulesetLabelName]**](StandaloneRulesetLabelName.md) | the labels that were deleted | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


